#include <iostream>
#include <vector>
#include <algorithm>

struct DSU {
    std::vector<int> e;
    DSU(int n) { e = std::vector<int>(n, -1); }
    int get(int x) { return e[x] < 0 ? x : e[x] = get(e[x]); }
    // bool same_set(int x, int y) { return get(x) == get(y); }
    bool unite(int x, int y) {
        x = get(x); y = get(y);
        if (x == y) return false;
        if (e[x] > e[y]) { std::swap(x, y); }
        e[x] += e[y]; e[y] = x;
        return true;
    }
};

struct edge {
    int u, v, w;
};

int n, m;
std::vector<edge> edges;

int kruskal() {
    std::sort(edges.begin(), edges.end(), [&] (edge a, edge b) {
        return a.w < b.w;
    });

    // std::cout<<"\n";
    DSU dsu(n); int res = 0;
    for(auto e : edges) {
        // std::cout<<e.u<<" "<<e.v<<" "<<e.w<<" ";
        if (dsu.unite(e.u, e.v)) {
            // std::cout<<1;
            res += e.w;
        }
        // std::cout<<"\n";
    }
    std::cout<<res<<"\n";
}

int main () {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(0);

    std::cin>>n>>m;
    for(int i = 0; i < m; i++) {
        int a, b, w; std::cin>>a>>b>>w;
        edges.push_back({a, b, w});
    }
    // std::cout<<kruskal()<<"\n";
    kruskal();
    return 0;
}

/*

9 12
1 2 1
2 3 1
4 5 1
5 6 1
7 8 1
8 9 1
1 4 1
4 7 1
2 5 1
5 8 1
3 6 1
6 9 1
*/
